import {
  Entity,
  Column,
  PrimaryGeneratedColumn,
  OneToMany,
  ManyToOne,
  JoinColumn,
} from 'typeorm';
import { Carrito } from '../carrito/entity/carrito.entity';
import { Motivo } from '../motivo/motivo.entity';
import { Prestamo } from '../prestamo/prestamo.entity';
import { Programa } from '../programa/programa.entity';
import { Status } from '../status/status.entity';
import { EquipoTipoEntrada } from '../equipo-tipo-entrada/equipo-tipo-entrada.entity';

@Entity()
export class Equipo {
  @PrimaryGeneratedColumn()
  id_equipo: number;

  @Column()
  equipo: string;

  @Column()
  numero_inventario: string;

  @Column()
  numero_serie: string;

  @Column()
  prestado: boolean;

  @ManyToOne(() => Carrito, (carrito) => carrito.equipos)
  @JoinColumn({ name: 'id_carrito' })
  carrito: Carrito;

  @ManyToOne(() => Status, (status) => status.equipos)
  @JoinColumn({ name: 'id_status' })
  status: Status;

  @ManyToOne(() => Programa, (programa) => programa.equipos)
  @JoinColumn({ name: 'id_programa' })
  programa: Programa;

  @OneToMany(() => Motivo, (motivo) => motivo.equipo)
  motivos: Motivo[];

  @OneToMany(() => Prestamo, (prestamo) => prestamo.equipo)
  prestamos: Prestamo[];

  @OneToMany(
    () => EquipoTipoEntrada,
    (equipoTipoEntrada) => equipoTipoEntrada.tipoEntrada,
  )
  equipoTipoEntradas: EquipoTipoEntrada[];
}
