import {
  ConflictException,
  Injectable,
  NotFoundException,
} from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { InstitucionService } from '../institucion/institucion.service';
import { Modulo } from './entity/modulo.entity';

@Injectable()
export class ModuloService {
  constructor(
    @InjectRepository(Modulo) private moduloRepository: Repository<Modulo>,
    private institucionService: InstitucionService,
  ) {}

  async create(id_institucion: number, modulo: string) {
    const institucion = await this.institucionService.findById(id_institucion);
    const nuevoModulo = this.moduloRepository.create({
      institucion,
      modulo,
    });

    return this.moduloRepository
      .findOne({ modulo, institucion })
      .then((existeModulo) => {
        if (existeModulo)
          throw new ConflictException(
            'Ya existe un módulo con este nombre, intente con otro nombre.',
          );
        return this.moduloRepository.save(nuevoModulo);
      })
      .then(() => ({ message: 'Se creo correctamente el módulo.' }));
  }

  findAll() {
    return this.moduloRepository.find();
  }

  findAllByIdInstitucion(id_institucion: number) {
    return this.institucionService
      .findById(id_institucion)
      .then((institucion) => this.moduloRepository.find({ institucion }));
  }

  findById(id_modulo: number) {
    return this.moduloRepository.findOne({ id_modulo }).then((modulo) => {
      if (!modulo) throw new NotFoundException('No existe este módulo.');
      return modulo;
    });
  }

  async update(attrs: Partial<Modulo>) {
    const modulo = await this.findById(attrs.id_modulo);

    return this.moduloRepository
      .findOne({ modulo: attrs.modulo, institucion: modulo.institucion })
      .then((existeModulo) => {
        if (existeModulo)
          throw new ConflictException(
            'Ya existe un módulo con este nombre, intente con otro nombre.',
          );
        Object.assign(modulo, attrs);
        return this.moduloRepository.save(modulo);
      })
      .then(() => ({
        message: 'Se actualizo correctamente la información del módulo.',
      }));
  }
}
