import {
  Entity,
  Column,
  PrimaryGeneratedColumn,
  ManyToOne,
  JoinColumn,
} from 'typeorm';
import { Equipo } from '../equipo/equipo.entity';
import { Operador } from '../operador/operador.entity';
import { Usuario } from '../usuario/usuario.entity';

@Entity()
export class Prestamo {
  @PrimaryGeneratedColumn()
  id_prestamo: number;

  @Column()
  activo: boolean;

  @Column()
  fecha_inicio: Date;

  @Column()
  hora_max_recoger: Date;

  @Column()
  hora_inicio: Date;

  @Column()
  hora_fin: Date;

  @Column()
  fecha_entrega: Date;

  @Column()
  cancelado_usuario: boolean;

  @Column()
  cancelado_operador: boolean;

  @ManyToOne(() => Usuario, (usuario) => usuario.prestamos)
  @JoinColumn({ name: 'id_usuario' })
  usuario: Usuario;

  @ManyToOne(() => Equipo, (equipo) => equipo.prestamos)
  @JoinColumn({ name: 'id_equipo' })
  equipo: Equipo;

  @ManyToOne(
    () => Operador,
    (operadorEntrega) => operadorEntrega.prestamosOperadorEntrega,
  )
  @JoinColumn({ name: 'id_operador_entrega' })
  operadorEntrega: Operador;

  @ManyToOne(
    () => Operador,
    (operadorRegreso) => operadorRegreso.prestamosOperadorRegreso,
  )
  @JoinColumn({ name: 'id_operador_regreso' })
  operadorRegreso: Operador;
}
